#!/usr/bin/env bash
#
# Runs nginx and switches out the configuration to mount jenkins under /jenkins
#

apt-get install nginx -y

cat << "END" > /etc/nginx/nginx.conf 
error_log /var/log/nginx/error.log info;
worker_processes 10;
events {
  worker_connections  1024;
}
http {
  log_format   main '$remote_addr - $remote_user [$time_local]  $status '
      '"$request" $body_bytes_sent "$http_referer" '
      '"$http_user_agent" "$http_x_forwarded_for"';
  access_log /var/log/nginx/access.log;

  upstream jenkins_server {
    server 127.0.0.1:8080;
  }

  server {
    listen 80;

    location /jenkins {
      proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
      proxy_set_header Host $http_host;
      proxy_redirect off;

      if (!-f $request_filename) {
        proxy_pass http://jenkins_server;
        break;
      }
    }
  }
}
END

service nginx restart